# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding field 'Event.user'
        db.add_column('googlecalendar_event', 'user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True), keep_default=False)

        # Adding field 'Event.add_date'
        db.add_column('googlecalendar_event', 'add_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, default=datetime.datetime(2010, 12, 14, 14, 49, 51, 749206), blank=True), keep_default=False)

        # Adding field 'Event.is_active'
        db.add_column('googlecalendar_event', 'is_active', self.gf('django.db.models.fields.BooleanField')(default=True), keep_default=False)

        # Adding M2M table for field sites on 'Calendar'
        db.create_table('googlecalendar_calendar_sites', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('calendar', models.ForeignKey(orm['googlecalendar.calendar'], null=False)),
            ('site', models.ForeignKey(orm['sites.site'], null=False))
        ))
        db.create_unique('googlecalendar_calendar_sites', ['calendar_id', 'site_id'])


    def backwards(self, orm):
        
        # Deleting field 'Event.user'
        db.delete_column('googlecalendar_event', 'user_id')

        # Deleting field 'Event.add_date'
        db.delete_column('googlecalendar_event', 'add_date')

        # Deleting field 'Event.is_active'
        db.delete_column('googlecalendar_event', 'is_active')

        # Removing M2M table for field sites on 'Calendar'
        db.delete_table('googlecalendar_calendar_sites')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'googlecalendar.account': {
            'Meta': {'object_name': 'Account'},
            'email': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'token': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'})
        },
        'googlecalendar.calendar': {
            'Meta': {'object_name': 'Calendar'},
            'account': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['googlecalendar.Account']"}),
            'calendar_id': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
            'color': ('django.db.models.fields.CharField', [], {'max_length': '10', 'blank': 'True'}),
            'default_share': ('django.db.models.fields.CharField', [], {'default': "'read'", 'max_length': '31', 'null': 'True', 'blank': 'True'}),
            'feed_uri': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['sites.Site']", 'symmetrical': 'False'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '255', 'db_index': 'True'}),
            'summary': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'timezone': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'uri': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
            'where': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'})
        },
        'googlecalendar.event': {
            'Meta': {'ordering': "('-start_time',)", 'unique_together': "(('calendar', 'slug'),)", 'object_name': 'Event'},
            'add_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'calendar': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['googlecalendar.Calendar']"}),
            'edit_uri': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'end_time': ('django.db.models.fields.DateTimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('incuna.db.models.AutoSlugField.AutoSlugField', [], {'db_index': 'True', 'max_length': '255', 'populate_from': "'title'", 'field_separator': "u'-'"}),
            'start_time': ('django.db.models.fields.DateTimeField', [], {}),
            'summary': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'uri': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True'}),
            'view_uri': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'googlecalendar.mediafilecontent': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'MediaFileContent', 'db_table': "'googlecalendar_event_mediafilecontent'"},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mediafile': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'googlecalendar_mediafilecontent_set'", 'to': "orm['medialibrary.MediaFile']"}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'mediafilecontent_set'", 'to': "orm['googlecalendar.Event']"}),
            'position': ('django.db.models.fields.CharField', [], {'default': "'default'", 'max_length': '10'}),
            'region': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'googlecalendar.richtextcontent': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'RichTextContent', 'db_table': "'googlecalendar_event_richtextcontent'"},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'richtextcontent_set'", 'to': "orm['googlecalendar.Event']"}),
            'region': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'text': ('django.db.models.fields.TextField', [], {'blank': 'True'})
        },
        'medialibrary.category': {
            'Meta': {'ordering': "['parent__title', 'title']", 'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['medialibrary.Category']"}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '150', 'db_index': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'medialibrary.mediafile': {
            'Meta': {'object_name': 'MediaFile'},
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['medialibrary.Category']", 'null': 'True', 'blank': 'True'}),
            'copyright': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '255'}),
            'file_size': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'type': ('django.db.models.fields.CharField', [], {'max_length': '12'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['googlecalendar']



from datetime import datetime

from django import forms
from django.utils.formats import localize_input
from django.utils.translation import ugettext_lazy as _

from googlecalendar.models import Event, Calendar

def get_current_time():
    return localize_input(datetime.now().strftime('%Y-%m-%d %I:%M'))

class AddEventForm(forms.ModelForm):
    """ Add event form for calendar_list page """
    calendar = forms.ModelChoiceField(queryset=Calendar.active)
    start_time = forms.SplitDateTimeField(widget=forms.SplitDateTimeWidget(), label=_('Start date and time'), help_text=_('e.g. %s' % get_current_time()))
    end_time = forms.SplitDateTimeField(widget=forms.SplitDateTimeWidget(), label=_('End date and time'), help_text=_('e.g. %s' % get_current_time()))

    def clean_end_time(self):
        start_time = self.cleaned_data['start_time']
        end_time = self.cleaned_data['end_time']
        if end_time < start_time:
            raise forms.ValidationError("End date can not be earlier than start date.")
        return end_time

    class Meta:
        model = Event
        fields = ('calendar', 'title', 'summary', 'start_time', 'end_time')

class AddEventCalendarForm(AddEventForm):
    """ Add event form for calendar page. Calendar is preset. """

    def __init__(self, *args, **kwargs):
        self.calendar = kwargs.pop('calendar')
        super(AddEventCalendarForm, self).__init__(*args, **kwargs)
        self.fields['calendar'].widget=forms.HiddenInput()
        self.fields['calendar'].initial=self.calendar




# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Account'
        db.create_table('googlecalendar_account', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('email', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('password', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('token', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
        ))
        db.send_create_signal('googlecalendar', ['Account'])

        # Adding model 'Calendar'
        db.create_table('googlecalendar_calendar', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('account', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['googlecalendar.Account'])),
            ('uri', self.gf('django.db.models.fields.CharField')(unique=True, max_length=255)),
            ('calendar_id', self.gf('django.db.models.fields.CharField')(unique=True, max_length=255)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=255, db_index=True)),
            ('where', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('color', self.gf('django.db.models.fields.CharField')(max_length=10, blank=True)),
            ('timezone', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('summary', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('feed_uri', self.gf('django.db.models.fields.CharField')(max_length=255, blank=True)),
            ('default_share', self.gf('django.db.models.fields.CharField')(default='read', max_length=31, null=True, blank=True)),
        ))
        db.send_create_signal('googlecalendar', ['Calendar'])

        # Adding model 'Event'
        db.create_table('googlecalendar_event', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('calendar', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['googlecalendar.Calendar'])),
            ('uri', self.gf('django.db.models.fields.CharField')(unique=True, max_length=255)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('slug', self.gf('incuna.db.models.AutoSlugField.AutoSlugField')(db_index=True, max_length=255, populate_from='title', field_separator=u'-')),
            ('edit_uri', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('view_uri', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('summary', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('start_time', self.gf('django.db.models.fields.DateTimeField')()),
            ('end_time', self.gf('django.db.models.fields.DateTimeField')()),
        ))
        db.send_create_signal('googlecalendar', ['Event'])

        # Adding unique constraint on 'Event', fields ['calendar', 'slug']
        db.create_unique('googlecalendar_event', ['calendar_id', 'slug'])

        # Adding model 'RichTextContent'
        db.create_table('googlecalendar_event_richtextcontent', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('text', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('parent', self.gf('django.db.models.fields.related.ForeignKey')(related_name='richtextcontent_set', to=orm['googlecalendar.Event'])),
            ('region', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('googlecalendar', ['RichTextContent'])

        # Adding model 'MediaFileContent'
        db.create_table('googlecalendar_event_mediafilecontent', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('parent', self.gf('django.db.models.fields.related.ForeignKey')(related_name='mediafilecontent_set', to=orm['googlecalendar.Event'])),
            ('region', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('mediafile', self.gf('django.db.models.fields.related.ForeignKey')(related_name='googlecalendar_mediafilecontent_set', to=orm['medialibrary.MediaFile'])),
            ('position', self.gf('django.db.models.fields.CharField')(default='default', max_length=10)),
        ))
        db.send_create_signal('googlecalendar', ['MediaFileContent'])


    def backwards(self, orm):
        
        # Removing unique constraint on 'Event', fields ['calendar', 'slug']
        db.delete_unique('googlecalendar_event', ['calendar_id', 'slug'])

        # Deleting model 'Account'
        db.delete_table('googlecalendar_account')

        # Deleting model 'Calendar'
        db.delete_table('googlecalendar_calendar')

        # Deleting model 'Event'
        db.delete_table('googlecalendar_event')

        # Deleting model 'RichTextContent'
        db.delete_table('googlecalendar_event_richtextcontent')

        # Deleting model 'MediaFileContent'
        db.delete_table('googlecalendar_event_mediafilecontent')


    models = {
        'googlecalendar.account': {
            'Meta': {'object_name': 'Account'},
            'email': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'token': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'})
        },
        'googlecalendar.calendar': {
            'Meta': {'object_name': 'Calendar'},
            'account': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['googlecalendar.Account']"}),
            'calendar_id': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
            'color': ('django.db.models.fields.CharField', [], {'max_length': '10', 'blank': 'True'}),
            'default_share': ('django.db.models.fields.CharField', [], {'default': "'read'", 'max_length': '31', 'null': 'True', 'blank': 'True'}),
            'feed_uri': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '255', 'db_index': 'True'}),
            'summary': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'timezone': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'uri': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
            'where': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'})
        },
        'googlecalendar.event': {
            'Meta': {'ordering': "('-start_time',)", 'unique_together': "(('calendar', 'slug'),)", 'object_name': 'Event'},
            'calendar': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['googlecalendar.Calendar']"}),
            'edit_uri': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'end_time': ('django.db.models.fields.DateTimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('incuna.db.models.AutoSlugField.AutoSlugField', [], {'db_index': 'True', 'max_length': '255', 'populate_from': "'title'", 'field_separator': "u'-'"}),
            'start_time': ('django.db.models.fields.DateTimeField', [], {}),
            'summary': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'uri': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
            'view_uri': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'googlecalendar.mediafilecontent': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'MediaFileContent', 'db_table': "'googlecalendar_event_mediafilecontent'"},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mediafile': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'googlecalendar_mediafilecontent_set'", 'to': "orm['medialibrary.MediaFile']"}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'mediafilecontent_set'", 'to': "orm['googlecalendar.Event']"}),
            'position': ('django.db.models.fields.CharField', [], {'default': "'default'", 'max_length': '10'}),
            'region': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'googlecalendar.richtextcontent': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'RichTextContent', 'db_table': "'googlecalendar_event_richtextcontent'"},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'richtextcontent_set'", 'to': "orm['googlecalendar.Event']"}),
            'region': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'text': ('django.db.models.fields.TextField', [], {'blank': 'True'})
        },
        'medialibrary.category': {
            'Meta': {'ordering': "['parent__title', 'title']", 'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['medialibrary.Category']"}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '150', 'db_index': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'medialibrary.mediafile': {
            'Meta': {'object_name': 'MediaFile'},
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['medialibrary.Category']", 'null': 'True', 'blank': 'True'}),
            'copyright': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'created': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '255'}),
            'file_size': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'type': ('django.db.models.fields.CharField', [], {'max_length': '12'})
        }
    }

    complete_apps = ['googlecalendar']



from django.conf.urls.defaults import patterns, url

urlpatterns = patterns('googlecalendar.views',
    url(r'^(?P<slug>[a-z0-9_-]+)/(?P<event>[a-z0-9_-]+)$', 'googlecalendar_event', name='googlecalendar_event'),
    url(r'^(?P<slug>[a-z0-9_-]+)/$', 'googlecalendar', name='googlecalendar_detail'),
    url(r'^$', 'googlecalendar_list', name='googlecalendar'),
)




from django.contrib import admin
from django import forms
from models import *
from incunafein.admin import editor
from django.conf import settings

class CalendarAdmin(admin.ModelAdmin):
    list_display = ['title', 'calendar_id', ]
    list_filter = ( 'account',)
    search_fields = ('title', 'slug', 'summary',)
    prepopulated_fields = {
        'slug': ('title',),
        }


class EventAdmin(editor.ItemEditor, admin.ModelAdmin):
    date_hierarchy = 'start_time'
    list_display = ('__unicode__', 'calendar', 'start_time', 'end_time',)
    list_filter = ( 'calendar',)
    search_fields = ('title', 'slug', 'summary',)
    prepopulated_fields = {
        'slug': ('title',),
        }
    actions = ['delete_selected', ]
    readonly_fields = ['user',]
    verbose_name_plural = 'Events'

    if hasattr(settings, 'TINYMCE_JS_URL'):
        # If available add TINYMCE (assumes settings.STATIC_URL+'scripts/tiny_init.js' is present)
        class Media:
            js = (settings.TINYMCE_JS_URL, settings.STATIC_URL+'scripts/tiny_init.js',)
    

    # override the default delete action to ensure that the event in the google calendar is also deleteed 
    def delete_selected(self, request, queryset):
        for e in queryset:
            e.delete()
    delete_selected.short_description = "Delete selected events!"


    def save_model(self, request, obj, form, change):
        if not change:
            obj.user = request.user
            obj.save()


admin.site.register(Account)
admin.site.register(Calendar, CalendarAdmin)
admin.site.register(Event, EventAdmin)




import re
import urllib
from django.db import models
from django.db.models import Q
import gdata
import atom
import datetime
from django.db.models import Manager
from utils import parse_date_w3dtf, format_datetime, to_role_uri, from_role_uri
from django.utils.translation import ugettext_lazy as _
from django.contrib.sites.models import Site


from feincms.models import Base
from feincms.content.medialibrary.models import MediaFileContent
from feincms.content.richtext.models import RichTextContent

import mptt
from incuna.db.models.AutoSlugField import AutoSlugField
from django.contrib.auth.models import User

VERSION = '0.3'

_services = {}

re_cal_id = re.compile(r".*/(.*)")


def with_request_error_try(function, attempts=3):
    """
    Attempt to call the function within a RequestError try / catch.
    """
    while True:
        try:
            return function()
        except gdata.service.RequestError, e:
            attempts -= 1
            if attempts == 0:
                raise
            if e.args[0]['status'] != 302:
                raise


class Account(models.Model):
    email = models.CharField(max_length = 100, blank = True)
    password = models.CharField(max_length = 100, blank = True)
    token = models.CharField(max_length = 100, blank = True)

    def __unicode__(self):
        if self.email:
            return u'Account for %s' % self.email
        else:
            return u'Account with token'

    @property
    def service(self):
        if not _services.has_key(self.email):
            _service = gdata.calendar.service.CalendarService()
            _service.source = 'ITSLtd-Django_Google-%s' % VERSION
            if self.token:
                _service.auth_token = self.token
            else:
                _service.email = self.email
                _service.password = self.password
                _service.ProgrammaticLogin()
                _services[self.email] = _service
        return _services[self.email]

    def get_own_calendars(self, commit=True):
        cals = self.service.GetOwnCalendarsFeed()
        result = []
        for cal in cals.entry:
            result.append(Calendar.objects.from_gcal(self, cal, commit=commit))
        return result


class CalendarManager(Manager):
    def from_gcal(self, account, gcal, commit=True):
        uri = gcal.id.text
        try:
            instance = self.get(uri = uri)
        except self.model.DoesNotExist:
            instance = self.model(account=account, uri=uri)

        # copy attributes from gcal
        for prop in ['title', 'where', 'summary', 'color', 'timezone', ]:
            attr = getattr(gcal, prop)
            if hasattr(attr, 'value'):
                setattr(instance, prop, attr.value or '')
            elif hasattr(attr, 'text'):
                setattr(instance, prop, attr.text or '')

        for link in gcal.link:
            if link.rel == 'alternate':
                instance.feed_uri = link.href
                break

        # Default Acl
        rule = instance.getAclRule('default')
        instance.default_share = rule and from_role_uri(rule.role.value)


        if commit:
            instance.save()

        return instance


    def active(self):
        " Returns calendars available for current site only."
        current_site = Site.objects.get_current()
        return super(CalendarManager, self).get_query_set().filter(sites=current_site)

class ActiveManager(CalendarManager):
    def get_query_set(self):
        return self.active()


class Calendar(models.Model):
    SHARE_CHOICES = (
        ('freebusy', _('See only free / busy (hide details)')),
        ('read', _('See all event details')),
    )
    account = models.ForeignKey(Account)
    uri = models.CharField(max_length = 255, unique = True, editable=False, help_text=_('Google calendar address. Leave blank to create a Google calendar.'))
    calendar_id = models.CharField(max_length = 255, editable=False, unique = True)
    title = models.CharField(max_length = 100)
    slug = models.SlugField(max_length = 255, help_text=_('This will be automatically generated from the  title'), unique=True)
    where = models.CharField(max_length = 100, blank = True, help_text=_('Location (e.g Oxford, UK).'))
    color = models.CharField(max_length = 10, blank = True, help_text=_('Leave blank to populate from Google.'))
    timezone = models.CharField(max_length = 100, blank = True, help_text=_('Leave blank to populate from Google.'))
    summary = models.TextField(blank=True, null=True)
    feed_uri = models.CharField(max_length = 255, blank = True, editable=False)

    default_share = models.CharField(_("Share with public"), max_length=31, blank = True, null = True, choices=SHARE_CHOICES, default=SHARE_CHOICES[1][0])

    sites = models.ManyToManyField(Site)

    objects = CalendarManager()
    active = ActiveManager()


    def __unicode__(self):
        return self.title

    @models.permalink
    def get_absolute_url(self):
        return ('googlecalendar_detail', (), {
                'calendar': self.slug,
                })

    def save(self):
        gcal = self.gCalendar
        if gcal:
            # existing calendar update
            new = False
        else:
            new = True
            gcal = gdata.calendar.CalendarListEntry()

        gcal.title = atom.Title(text=self.title)
        gcal.summary = atom.Summary(text=self.summary)
        if self.where:
            gcal.where = gdata.calendar.Where(value_string=self.where)
        elif gcal.where and gcal.where.text:
            self.where = gcal.where.text
        if self.color:
            gcal.color = gdata.calendar.Color(value=self.color)
        elif gcal.color and gcal.color.value:
            self.color = gcal.color.value
        if self.timezone:
            gcal.timezone = gdata.calendar.Timezone(value=self.timezone)
        elif gcal.timezone and gcal.timezone.value:
            self.timezone = gcal.timezone.value

        if new:
            new_gcal = with_request_error_try(lambda: self.account.service.InsertCalendar(new_calendar=gcal))
            # gooogle replaces the title with the (email address) style Calendar Id
            #self.calendar_id = new_gcal.title.text
            new_gcal.title = atom.Title(text=self.title)
            new_gcal = self.account.service.UpdateCalendar(calendar=new_gcal)

            self.uri = new_gcal.id.text
            for link in new_gcal.link:
                if link.rel == 'alternate':
                    self.feed_uri = link.href
                    break

        else:
            new_gcal = with_request_error_try(lambda: self.account.service.UpdateCalendar(calendar=gcal))

        m = re_cal_id.match(self.uri)
        if m:
            self.calendar_id = urllib.unquote(m.group(1))

        # ACL model
        rule = self.getAclRule('default')
        if not self.default_share:
            # Not sharing
            if rule is not None:
                # remove the rule
                with_request_error_try(lambda: self.account.service.DeleteAclEntry(rule.GetEditLink().href))
        else:
            if rule is None:
                # new rule
                self.setAclRule(role=self.default_share, scope_type='default')
            elif to_role_uri(self.default_share) != rule.role.value:
                # role change
                self.setAclRule(rule=rule, role=self.default_share)


        super(Calendar, self).save()


    @property
    def upcoming_events(self):
        now = datetime.datetime.now()
        return self.event_set.filter(Q(start_time__gte=now) | Q(end_time__gte=now)).order_by('start_time')

    @property
    def gCalendar(self):
        if getattr(self, '_gCalendar', None):
            return self._gCalendar
        if self.uri:
            for c in self.account.service.GetOwnCalendarsFeed().entry:
                if self.uri == c.id.text:
                    self._gCalendar = c
                    return self._gCalendar

        return None

    def getAclRule(self, scope_type='default',):
        gcal = self.gCalendar
        if not gcal:
            return None
        aclink = gcal.GetAclLink()

        try:
            #try to get the entry
            return self.account.service.GetCalendarAclEntry('%s/%s' % (aclink.href, scope_type))
        except gdata.service.RequestError, e:
            if e.args[0]['reason'] != 'Not Found':
                raise
            return None


    def setAclRule(self, rule=None, role='read', scope_type='default', scope_value=None):
        """
        Set the role for a rule. If no rule is specified a new rule will be created with the provides scope_type / scope_type.
        """

        gcal = self.gCalendar
        if not gcal:
            return None
        aclink = gcal.GetAclLink()

        newRole = gdata.calendar.Role(value=to_role_uri(role))

        if rule is None:
            # add the entry
            rule = gdata.calendar.CalendarAclEntry()

            rule.scope = gdata.calendar.Scope()
            rule.scope.type = scope_type
            if scope_value:
                rule.scope.value = scope_value

            rule.role = newRole
            return with_request_error_try(lambda: self.account.service.InsertAclEntry(rule, aclink.href))
        else:
            # update the entry
            rule.role = newRole
            return with_request_error_try(lambda: self.account.service.UpdateAclEntry(rule.GetEditLink().href, rule))


    def get_events(self, commit=True):
        events = self.account.service.GetCalendarEventFeed(uri = self.feed_uri)
        result = []
        for i, event in enumerate(events.entry):
            result.append(Event.objects.from_gcal(self, event, commit=commit))
        return result


class EventManager(Manager):
    def from_gcal(self, calendar, data, commit=True):
        uri = data.id.text
        try:
            instance = self.get(uri = uri)
        except self.model.DoesNotExist:
            instance = self.model(calendar = calendar, uri = uri)

        instance.title = data.title.text or ''
        instance.summary = data.content.text or ''
        instance.start_time = parse_date_w3dtf(data.when[0].start_time)
        instance.end_time = parse_date_w3dtf(data.when[0].end_time)
        instance.edit_uri = data.GetEditLink().href
        instance.view_uri = data.GetHtmlLink().href

        if commit:
            instance.save()

        return instance

    def upcoming(self):
        """Current (and upcoming component)"""
        now = datetime.datetime.now()
        return self.active().filter(Q(start_time__gte=now) | Q(end_time__gte=now)).order_by('start_time')


    def active(self):
        " Returns events for those calendars that available for current site only."
        current_site = Site.objects.get_current()
        return super(EventManager, self).get_query_set().filter(calendar__sites=current_site, is_active=True)


class Event(Base):
    calendar = models.ForeignKey(Calendar)
    uri = models.CharField(max_length = 255, unique = True, editable=False)
    title = models.CharField(max_length = 255)
    slug = AutoSlugField(max_length = 255, populate_from='title', editable=True, help_text=_('This will be automatically generated from the  title'))
    edit_uri = models.CharField(max_length = 255, editable=False)
    view_uri = models.CharField(max_length = 255, editable=False)
    summary = models.TextField(blank = True)
    start_time = models.DateTimeField()
    end_time = models.DateTimeField()

    user = models.ForeignKey(User, null=True)
    add_date = models.DateTimeField(_('Date added'), auto_now_add=True)
    is_active = models.BooleanField(_('active'), default=True, )

    objects = EventManager()

    class Meta:
        ordering = ('-start_time',)
        get_latest_by = 'start_time'
        unique_together = ('calendar', 'slug')

    def __unicode__(self):
        return u'%s' % (self.title)

    @models.permalink
    def get_absolute_url(self):
        return ('googlecalendar_event', (), {
                'slug': self.calendar.slug,
                'event': self.slug,
                })

    def save(self):

        self._meta.get_field('slug').pre_save(self, not self.pk)

        content = self.summary
        content += """<p><a target="_top" href="%s%s">Full event details</a></p>""" % (Site.objects.get_current().domain, self.get_absolute_url(), )

        if self.uri:
            # existing event, update
            entry = self.calendar.account.service.GetCalendarEventEntry(uri = self.edit_uri)
            entry.title.text = self.title
            entry.content.text = content
            start_time = format_datetime(self.start_time)
            end_time = format_datetime(self.end_time)
            entry.when = []
            entry.when.append(gdata.calendar.When(start_time = start_time, end_time = end_time))
            new_entry = with_request_error_try(lambda: self.calendar.account.service.UpdateEvent(entry.GetEditLink().href, entry))
        else:
            entry = gdata.calendar.CalendarEventEntry()
            entry.title = atom.Title(text = self.title)
            entry.content = atom.Content(text = content)
            if not self.start_time:
                self.start_time = datetime.datetime.utcnow()
            if not self.end_time:
                self.end_time = self.start_time + datetime.timedelta(hours = 1)
            start_time = format_datetime(self.start_time)
            end_time = format_datetime(self.end_time)
            entry.when.append(gdata.calendar.When(start_time = start_time, end_time = end_time))
            new_entry = with_request_error_try(lambda: self.calendar.account.service.InsertEvent(entry, self.calendar.feed_uri))
            self.uri = new_entry.id.text
            self.edit_uri = new_entry.GetEditLink().href
            self.view_uri = new_entry.GetHtmlLink().href

        super(Event, self).save()

    def delete(self):
        if self.uri:
            try:
                # existing event, delete
                self.calendar.account.service.DeleteEvent(self.edit_uri)
            except gdata.service.RequestError, e:
                if e.args[0]['status'] != 404:
                    raise
        super(Event, self).delete()

Event.register_regions(
    ('main', _('Main region')),
    )
Event.create_content_type(RichTextContent)
Event.create_content_type(MediaFileContent, POSITION_CHOICES=(('default', _('Default')),))





import urllib
import itertools
from django.conf import settings
from django import template 
from django.forms.util import flatatt
from django.utils.safestring import mark_safe
from googlecalendar.utils import request_single_token
from googlecalendar.models import Calendar, Event

GOOGLECALENDAR_DEFAULTS = dict(
    # iframe attributes 
    style=" border-width:0 ", 
    width="800",
    height="600", 
    frameborder="0", 
    scrolling="no",
    # Calender attributes
    showTitle="0", 
    showCalendars="1", 
    showTz="0", 
    wkst="1", 
    bgcolor="#FFFFFF", 
    ctz="Europe/London")

IFRAME_ATTRS = (
    'style',
    'width',
    'height',
    'frameborder',
    'scrolling',
    'longdesc',
    'marginheight',
    'marginwidth',
)

if hasattr(settings, 'GOOGLECALENDAR_DEFAULTS'):
    GOOGLECALENDAR_DEFAULTS.update(settings.GOOGLECALENDAR_DEFAULTS)

register = template.Library()

class GoogleCalendarAuthNode(template.Node):
	def __init__(self, uri):
		self.uri = uri
	def render(self, context):
		uri = template.resolve_variable(self.uri, context)
		return request_single_token(uri)

@register.tag
def google_calendar_auth(parser, token):
	bits = token.contents.split()
	len_bits = len(bits)
	if len_bits != 2:
		raise template.TemplateSyntaxError('%s tag requires URI as an argument' % bits[0])
	return GoogleCalendarAuthNode(bits[1])


class CalendarNode(template.Node):
    """
        Render a google calendar (iframe) embed.

        Usage:
            {% calendar %}
            {% calendar 'joe@gmail.com' %}
            {% calendar 'joe@gmail.com' width="580" height="350" %}
            {% calendar 'joe@gmail.com' 'james@gmail.com' width="580" height="350" %}
            {% calendar 'joe@gmail.com' 'james@gmail.com' calendar_instance width="580" height="350" %}
    """

    COLOURS = ['#D96666', '#E67399', '#8C66D9', '#668CB3', '#668CD9', '#59BFB3', '#65AD89', '#4CB052', '#8CBF40', '#E0C240',
               '#E6804D', '#BE9494', '#A992A9', '#8997A5', '#94A2BE', '#85AAA5', '#A7A77D', '#C4A883', '#C7561E', '#B5515D',
               '#C244AB', '#603F99', '#536CA6', '#3640AD', '#3C995B', '#5CA632', '#7EC225', '#A7B828', '#CF9911', '#D47F1E',
               '#B56414', '#914D14', '#AB2671', '#9643A5', '#4585A3', '#737373', '#41A587', '#D1BC36', '#AD2D2D', ]

    @staticmethod
    def colours(start = 0):
        """
        Returns a stream of colours, if the end of the list is reached then it starts back at the beginning.
        """
        while True:
            try:
                yield CalendarNode.COLOURS[start]
            except IndexError:
                start = 0
                yield CalendarNode.COLOURS[start]
            start += 1

    def __init__(self, *args, **kwargs):
        self.calendars = args
        self.attrs = kwargs

    def render(self, context):

        iframe_attrs = {}
        calendar_attrs = {}
        for key, value in GOOGLECALENDAR_DEFAULTS.items():
            if key in IFRAME_ATTRS:
                iframe_attrs[key] = value
            else:
                calendar_attrs[key] = value



        if not self.calendars:
            calendars = Calendar.objects.active()
        else:
            calendars = []
            def add_calendars(cals):
               for cal in cals:

                   if isinstance(cal, basestring):
                       try:
                           cal = Calendar.objects.active().get(calendar_id=cal)
                       except Calendar.DoesNotExist:
                           continue
                   elif getattr(cal, '__iter__', False):#isinstance(cal, (list, tuple)):
                       add_calendars(cal)
                       continue

                   calendars.append(cal)

            add_calendars([cal.resolve(context) for cal in self.calendars])

        if not calendars:
            return ''

        for key in self.attrs:
            value = self.attrs[key].resolve(context) or self.attrs[key]
            if key in IFRAME_ATTRS:
                iframe_attrs[key] = value
            else:
                calendar_attrs[key] = value

        colours = self.colours()
        src = "https://www.google.com/calendar/embed?%s" % ( '&'.join(["%s=%s" % (k, urllib.quote(v)) for k, v in calendar_attrs.items()]) )
        for calendar in calendars:
            src += "&src=%s&color=%s" % tuple(map(urllib.quote, (calendar.calendar_id, calendar.color or colours.next())))

        iframe_attrs['src'] = src

        return mark_safe(u'<iframe%s ></iframe>' % flatatt(iframe_attrs))

@register.tag()
def embedcalendar(parser, token):
    bits = token.split_contents() 

    calendars = []
    dict = {}
    try:
        for bit in bits[1:]:
            try:
                bit.index('=')
            except ValueError:
                calendars.append(parser.compile_filter(bit))
            else:
                pair = bit.split('=')
                dict[str(pair[0])] = parser.compile_filter(pair[1])
    except TypeError:
        raise template.TemplateSyntaxError('Bad arguments for tag "%s"' % bits[0])

    return CalendarNode(*calendars, **dict)


class CalendarEventsNode(template.Node):
    """

    """
    def __init__(self, calendars=None, limit=None, varname=None):
        self.calendars = calendars
        self.limit = limit
        self.varname = varname

    def render(self, context):
        calendars = self.calendars and self.calendars.resolve(context)
        limit = self.limit and self.limit.resolve(context)


        events = Event.objects.upcoming()

        if calendars is None:
            pass
        elif isinstance(calendars, (str,unicode,)):
            try:
                calendars = [Calendar.objects.active().get(slug=calendars)]
            except Calendar.DoesNotExist:
                calendars = None

        elif not getattr(calendars, '__iter__', False):
            calendars = [calendars]


        if calendars is not None:
            events = events.filter(calendar__in=calendars)

        if limit is not None:
            events = events[:limit]

        if self.varname is not None:
            context[self.varname] = events
            return ''
        else:
            t = template.loader.select_template(['googlecalendar/events.html'])
            context.push()
            context['calendars'] = calendars
            context['events'] = events
            output = t.render(context)
            context.pop()

            return output


@register.tag()
def calendarevents(parser, token):
    bits = token.split_contents() 

    if bits[-2] == 'as':
        varname = bits[-1]
        args = bits[1:-2]
    else:
        args = bits[1:]
        varname = None

    return CalendarEventsNode(*map(parser.compile_filter, args), varname=varname)




from setuptools import setup, find_packages

from googlecalendar import get_version
setup(
    name = "django-googlecalendar",
    packages = find_packages(),
    install_requires=[
        "gdata",
        "FeinCMS",
    ],
    version = get_version(),
    description = "This project implements Google Calendar API as django objects.",
    author = "Incuna Ltd",
    author_email = "admin@incuna.com",
    url = "http://incuna.com/",
    include_package_data=True,
)



import re
import time
import datetime
import gdata.calendar.service
from django.utils.tzinfo import FixedOffset, LocalTimezone

DATE_FORMAT = '%Y-%m-%dT%H:%M:%S.000Z'
ROLE_URI_ROOT = 'http://schemas.google.com/gCal/2005#'

def format_datetime(date):
    """
    A utility method that converts the datetime to UTC serialized
    for Google Calendar.
    """
    local = date.replace(tzinfo=LocalTimezone(date))
    return local.astimezone(FixedOffset(0)).strftime(DATE_FORMAT)

def to_role_uri(role):
    return '%s%s' % (ROLE_URI_ROOT, role, )

def from_role_uri(role):
    return role.replace(ROLE_URI_ROOT, '')


def parse_date_w3dtf(dateString):
    def __extract_date(m):
        year = int(m.group('year'))
        if year < 100:
            year = 100 * int(time.gmtime()[0] / 100) + int(year)
        if year < 1000:
            return 0, 0, 0
        julian = m.group('julian')
        if julian:
            julian = int(julian)
            month = julian / 30 + 1
            day = julian % 30 + 1
            jday = None
            while jday != julian:
                t = time.mktime((year, month, day, 0, 0, 0, 0, 0, 0))
                jday = time.gmtime(t)[-2]
                diff = abs(jday - julian)
                if jday > julian:
                    if diff < day:
                        day = day - diff
                    else:
                        month = month - 1
                        day = 31
                elif jday < julian:
                    if day + diff < 28:
                       day = day + diff
                    else:
                        month = month + 1
            return year, month, day
        month = m.group('month')
        day = 1
        if month is None:
            month = 1
        else:
            month = int(month)
            day = m.group('day')
            if day:
                day = int(day)
            else:
                day = 1
        return year, month, day
    def __extract_time(m):
        if not m:
            return 0, 0, 0
        hours = m.group('hours')
        if not hours:
            return 0, 0, 0
        hours = int(hours)
        minutes = int(m.group('minutes'))
        seconds = m.group('seconds')
        if seconds:
            seconds = int(float(seconds))
        else:
            seconds = 0
        return hours, minutes, seconds
    def __extract_tzd(m):
        '''Return the Time Zone Designator as an offset in seconds from UTC.'''
        if not m:
            return 0
        tzd = m.group('tzd')
        if not tzd:
            return 0
        if tzd == 'Z':
            return 0
        hours = int(m.group('tzdhours'))
        minutes = m.group('tzdminutes')
        if minutes:
            minutes = int(minutes)
        else:
            minutes = 0
        offset = (hours*60 + minutes)
        if tzd[0] == '+':
            return -offset
        return offset
    __date_re = ('(?P<year>\d\d\d\d)'
                 '(?:(?P<dsep>-|)'
                 '(?:(?P<julian>\d\d\d)'
                 '|(?P<month>\d\d)(?:(?P=dsep)(?P<day>\d\d))?))?')
    __tzd_re = '(?P<tzd>[-+](?P<tzdhours>\d\d)(?::?(?P<tzdminutes>\d\d))|Z)'
    __tzd_rx = re.compile(__tzd_re)
    __time_re = ('(?P<hours>\d\d)(?P<tsep>:|)(?P<minutes>\d\d)'
                 '(?:(?P=tsep)(?P<seconds>\d\d(?:[.,]\d+)?))?'
                 + __tzd_re)
    __datetime_re = '%s(?:T%s)?' % (__date_re, __time_re)
    __datetime_rx = re.compile(__datetime_re)
    m = __datetime_rx.match(dateString)
    if (m is None) or (m.group() != dateString): return
    gmt = __extract_date(m) + __extract_time(m)
    if gmt[0] == 0: return
    return datetime.datetime(tzinfo = None, *gmt) + datetime.timedelta(minutes = __extract_tzd(m))

def request_single_token(uri, secure = False, session = True):
    '''
    Call this to get an authorization link
    (will be redirected back to uri provided with 'token' in request.GET)
    '''
    service = gdata.calendar.service.CalendarService()
    scope = 'http://www.google.com/calendar/feeds/'
    return service.GenerateAuthSubURL(uri, scope, secure, session)

def upgrade_token(token):
    '''
    Upgrade a token obtained by request_single_token to a session token
    usable in the Account model
    '''
    service = gdata.calendar.service.CalendarService()
    service.auth_token = token
    service.UpgradeToSessionToken()
    return service.auth_token

def list_cals(account):
    cals = account.get_own_calendars()
    for c in cals:
        print c
        print '--- EVENTS:'
        for e in c.get_events():
            print e




from django.db.models import Manager
from utils import parse_date_w3dtf

class CalendarManager(Manager):
    def get_or_create(self, account, data):
        uri = data.id.text
        try:
            result = self.get(uri = uri)
        except self.model.DoesNotExist:
            result = self.model(account = account)
        result.uri = uri
        for prop in ['color', 'summary', 'timezone', 'title', 'where']:
            attr = getattr(data, prop)
            if hasattr(attr, 'text'):
                setattr(result, prop, attr.text or '')
        for link in data.link:
            if link.rel == 'alternate':
                result.feed_uri = link.href
        return result

class EventManager(Manager):
    def get_or_create(self, calendar, data):
        uri = data.id.text
        try:
            result = self.get(uri = uri)
        except self.model.DoesNotExist:
            result = self.model(calendar = calendar)
        result.title = data.title.text or ''
        result.content = data.content.text or ''
        result.start_time = parse_date_w3dtf(data.when[0].start_time)
        result.end_time = parse_date_w3dtf(data.when[0].end_time)
        result.edit_uri = data.GetEditLink().href
        result.view_uri = data.GetHtmlLink().href
        return result




from django.conf import settings
from django.contrib import messages
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.core.mail import mail_admins
from django.shortcuts import get_object_or_404, render_to_response
from django.template import RequestContext
from django.utils.translation import ugettext_lazy as _

from forms import AddEventForm, AddEventCalendarForm
from models import Calendar, Event

def googlecalendar_list(request, extra_context=None, template_name='googlecalendar/calendar_list.html'):
    context = RequestContext(request)
    if extra_context is not None:
        context.update(extra_context)

    active_calendars = Calendar.active.all()
    if not active_calendars:
        subject = 'Missing Calendars'
        message = 'There are no calendars currently associated with %s' % settings.SITE_NAME
        mail_admins(subject, message)
        messages.add_message(request, messages.INFO, _('An error has occurred with the calendars.'))
        return HttpResponseRedirect('/')

    event_form = None
    if hasattr(settings, 'USER_ADD_EVENTS') and settings.USER_ADD_EVENTS:
        event_form = AddEventForm()

        if request.method == 'POST':
            event_form = AddEventForm(request.POST)
            if event_form.is_valid():
                event = event_form.save(commit=False)
                if request.user.is_authenticated():
                    event.user = request.user
                event.save()

                event_form = AddEventForm()
                messages.add_message(request, messages.INFO, _('New event was successfully saved'))
                return HttpResponseRedirect(reverse('googlecalendar'))

    context.update({'object_list': active_calendars, 'event_form': event_form})
    return render_to_response(template_name, context)

def googlecalendar(request, slug, extra_context=None, template_name='googlecalendar/calendar_detail.html'):
    context = RequestContext(request)
    if extra_context is not None:
        context.update(extra_context)

    calendar = get_object_or_404(Calendar.active, slug=slug)

    event_form = None
    if hasattr(settings, 'USER_ADD_EVENTS') and settings.USER_ADD_EVENTS:
        event_form = AddEventCalendarForm(calendar=calendar)

        if request.method == 'POST':
            event_form = AddEventCalendarForm(request.POST, calendar=calendar)
            if event_form.is_valid():
                event_form.save()
                event_form = AddEventCalendarForm(calendar=calendar)
                messages.add_message(request, messages.INFO, _('New event was successfully saved'))

    context.update({'object': calendar, 'event_form' : event_form})
    return render_to_response(template_name, context)

def googlecalendar_event(request, slug, event, extra_context=None, template_name='googlecalendar/event_detail.html'):
    context = RequestContext(request)
    if extra_context is not None:
        context.update(extra_context)

    context.update({'object': get_object_or_404(Event.objects.active(), slug=event, calendar__slug=slug)})
    return render_to_response(template_name, context)

